# Publications

## Overview

This maintains a list of publications (journals, conferences, ...) where IESopt was applied as part of the modeling
approach. Entries are in alphabetical order. If you want to contribute a new publication or project, please follow the
instructions in the [section on contributing](#contributing) below.

## List of references

### (Mariuzzo, 2025)

:**title**: Grid-friendly optimization of energy communities through enhanced multiple participation
:**publication**: [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-blue?style=social)]([https://publications.ait.ac.at/de/publications/grid-friendly-optimization-of-energy-communities-through-enhanced/fingerprints/?sortBy=alphabetically)
:**project**: -
:**abstract**: Energy communities have been designed to promote sustainable development in the form of improved and affordable energy access, sustainable generation, and social inclusion. Thus, in this study, an optimization model is proposed to allocate the demand and production of each participant, generation unit, and storage initially belonging to different communities that are implemented under the same distribution transformer and engage in multiple participation. Both energy- and grid-related costs are minimized, and the benchmark independent energy community case is compared with the novel multiple participation.
:**keywords**: Energy communities, Multiple participation, Linear programming, Peak load, Load shedding
:**citation**: Mariuzzo, I., Fina, B., Strömer, S., Corinaldesi, C., & Raugi, M. (2025). Grid-friendly Optimization of Energy Communities through Enhanced Multiple Participation. Renewable and Sustainable Energy Reviews, 208(115028), 1-14. Artikel 115028.

---

### Heat Highway (Marx, SES 2023)

:**title**: Heat Highway - Heat Transmission Network Design Optimization and Robustness Analysis for a Case Study in Tyrol - Methodology
:**publication**: [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-blue?style=social)](https://publications.ait.ac.at/en/publications/heat-highway-heat-transmission-network-design-optimization-and-ro)
:**abstract**: The majority of district heating (DH) networks today are fueled by combustion processes based on fossil or biogenic fuels. For the decarbonization of DH networks various uncertainties regarding the future development of key factors, such as energy prices, need to be considered. Within the project “HeatHighway” a hypothetical inter-regional heat transfer network (HTN) in the region of the Inn valley in Tyrol, Austria was investigated.
:**keywords**: Future district heating, Waste heat sources, 4th generation DH, Heat transmission networks, Deterministic optimization, Monte Carlo simulation
:**citation**: Marx, N. O., Schmidt, R. R., Blakcori, R., Maggauer, K., Strömer, S., & Forster, T. (2023, September). Heat Highway - Heat Transmission Network Design Optimization and Robustness Analysis for a Case Study in Tyrol - Methodology. In _9th International Conference on Smart Energy Systems_ (pp. 103-104).

---

### H2REAL (Ortmann, EEM 2024)

:**title**: Development of a Global Market Model for Renewable Hydrogen
:**publication**: [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-blue?style=social)](https://publications.ait.ac.at/en/publications/development-of-a-global-market-model-for-renewable-hydrogen)
:**project**: [H2REAL](#references-projects-h2real)
:**abstract**: Considerable effort has been devoted to obtaining price indications for renewable hydrogen, reflecting the high interest in this topic. The focus of the present work is to combine the existing fundamental data into a market model to find a cost-minimizing equilibrium solution for a hypothetical ideal global hydrogen market in 2030. By combining data on planned production projects with LCOH estimations, a supply curve can be constructed for each region. Demand for renewable hydrogen is derived from European regulation such as the Renewable Energy Directive. Equilibrium prices, including marginal costs for transportation via ship or pipeline, range between €2.5 and 3.5 €/kg. The cost-optimal solution of the model also provides insights on the most efficient production sites as well as transport flows. It is observable that anticipated European production is adequate to meet demand, with flows within Europe mainly occurring from the North to the South.
:**keywords**: Renewable energy sources, Energy Markt Modelling, Hydrogen Market, Hydrogen Price Projections, Renewable Hydrogen
:**citation**: Ortmann, P., Reuter, S., & Strömer, S. (2024). Development of a Global Market Model for Renewable Hydrogen. In _20th International Conference on the European Energy Market (EEM)_(pp. 1-6).

---

### H2REAL (Ortmann, EnInnov 2024)

:**title**: Entwicklung eines globalen Marktmodells für Wasserstoff
:**publication**: [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-blue?style=social)](https://publications.ait.ac.at/de/publications/entwicklung-eines-globalen-marktmodells-f%C3%BCr-wasserstoff)
:**project**: [H2REAL](#references-projects-h2real)
:**abstract**: -
:**keywords**: Wasserstoff, Erzeugungskosten, Marktmodell Wasserstoff
:**citation**: Ortmann, P., Reuter, S., & Strömer, S. (2024). Entwicklung eines globalen Marktmodells für Wasserstoff. In _Entwicklung eines globalen Marktmodells für Wasserstoff_.

---

### HyTechonomy (Reuter, SES 2023)

:**title**: Optimizing the Domestic Production and Infrastructure for Green Hydrogen in Austria for 2030
:**publication**: [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-blue?style=social)](https://publications.ait.ac.at/en/publications/optimizing-the-domestic-production-and-infrastructure-for-green-h)
:**project**: [HyTechonomy](#references-projects-hytechonomy)
:**abstract**: The decarbonisation of the Austrian energy system is expected to be facilitated by the uptake of hydrogen-based technologies, which requires the establishment of a hydrogen infrastructure to meet the rising demand. While large quantities of hydrogen are expected to be imported in the future, current developments in the energy market suggest that domestic production of hydrogen should not be ignored to ensure the security of supply. As domestic production ramps up, locating electrolysers to ensure optimal system integration is still an open question. To address this challenge, the "HyTechonomy" project developed an optimisation model that identifies the most promising domestic locations for green hydrogen production and optimal means of hydrogen transport for the year 2030.
:**keywords**: Hydrogen infrastructure, Energy system modelling, centralised electrolysis, decentralised electrolysis
:**citation**: Reuter, S., Strömer, S., Traninger, M., & Beck, A. (2023, September). Optimizing the Domestic Production and Infrastructure for Green Hydrogen in Austria for 2030. In _Book of Abstracts: 9th International Conference on Smart Energy Systems_ (pp. 278-279).

---

### HyTechnonomy (Strömer, 2024)

:**title**: Transitioning to a Renewable Hydrogen System: Optimal Infrastructure for Self-sufficient Hydrogen Supply in Austria by 2030
:**publication**: : [![CITATION](https://img.shields.io/badge/DOI-10.1016%2Fj.segy.2024.100151-none?style=social)](https://doi.org/10.1016/j.segy.2024.100151)
:**project**: [HyTechonomy](#references-projects-hytechonomy)
:**abstract**: In this study, we employ an optimization model to optimally design a self-sufficient, independent of any imports and exports, hydrogen infrastructure for Austria by 2030. Our approach integrates key hydrogen technologies within a detailed spatial investment and operation model – coupled with a European scale electricity market model. We focus on optimizing diverse infrastructure components including trailers, pipelines, electrolyzers, and storages to meet Austria's projected hydrogen demand. To accurately estimate this demand in hourly resolution, we combine existing hydrogen strategies and projections to account for developments in various industrial sectors, consider demand driven by the transport sector, and integrate hydrogen demand arising from its use in gas-powered plants. Accounting for the inherent uncertainty linked to such projections, we run the analysis for two complementary scenarios. Our approach addresses the challenges of integrating large quantities of renewable hydrogen into a future energy system by recognizing the critical role of domestic production in the early market stages. The main contribution of this work is to address the gap in optimizing hydrogen infrastructure for effective integration of domestic renewable hydrogen production in Austria by 2030, considering sector coupling potentials, optimal electrolyzer placement, and the design of local hydrogen networks.
:**keywords**: Hydrogen, Renewable energy, Infrastructure modeling, Energy system modeling, Optimization
:**citation**: Strömer, S., Beck, A., Traninger, M., Orsolits, D., Reuter, S. (2024). Transitioning to a renewable hydrogen system: Optimal infrastructure for self-sufficient hydrogen supply in Austria by 2030. In _Smart Energy Volume 15(2024)_ (pp. 1-17).

---

## Contributing

To contribute a new reference, either

- fork the [iesopt](https://github.com/ait-energy/iesopt) repository, and directly add to the above list, or
- open an issue with the reference details.

See the template below for the structure of a reference.

### Template

Please stick to APA format here, and always include a link as badge (if possible a DOI, if not other links are okay
too).

`````markdown
### Custom header

:**title**: put the full title here
:**publication**: [![CITATION](url-of-your-badge)](link-to-doi-or-pure-or-other)
:**project**: [Project (short) name](#references-projects-shortname)
:**abstract**: put the abstract here
:**keywords**: put all keywords here
:**citation**: put the APA styled citation here

---
`````

The `project` can be left out if not applicable. Otherwise it should refer to a proper project link target, that is set.

The "custom header" is used to prevent overly long titles from messing up the overall readability. The proposed format looks like this:

```markdown
### TheFundingProject (FirstAuthor, Year)
```

Where `TheFundingProject` is the project this publication was mainly funded by. If no project is related, then just doing `### (FirstAuthor, Year)` is the preferred fallback. `FirstAuthor` is only the last name of the first author; `Year` is the date of publication listed in the official citation. If the entry refers to a conference use `### FundingProject (FirstAuthor, Conf. Year)`, e.g., `ProjectX (Jane Doe, IEWT 2023)`.

### Creating citation badges

You can use [shields.io](https://shields.io/badges) to create badges, or use standardized ones that you already have
(e.g., from Zenodo), otherwise stick to the ones provided below.

**Pure:** _(publications.ait.ac.at)_

> ```markdown
> [![CITATION](https://img.shields.io/badge/PURE-publications.ait.ac.at-none?style=social)](ADDYOURLINKHERE)
> ```

**DOI:**

> ```markdown
> [![CITATION](https://img.shields.io/badge/DOI-10.XXXX%2Fname.YYYY.ZZZZZZ-none?style=social)](https://doi.org/10.XXXX/name.YYYY.ZZZZZZ)
> ```
